# Русско-английский словарь для транспилятора "русский Python"
# Ключевые слова и часто используемые встроенные функции

RUSPY_DICT = {
    # Недостающие технические слова и исключения Python
    'арифметическая_ошибка': 'ArithmeticError',
    'группа_базовых_исключений': 'BaseExceptionGroup',
    'ошибка_блокировки_ввода_вывода': 'BlockingIOError',
    'ошибка_разорванного_канала': 'BrokenPipeError',
    'ошибка_буфера': 'BufferError',
    'ошибка_дочернего_процесса': 'ChildProcessError',
    'ошибка_прерванного_соединения': 'ConnectionAbortedError',
    'ошибка_соединения': 'ConnectionError',
    'ошибка_отказа_в_соединении': 'ConnectionRefusedError',
    'ошибка_сброса_соединения': 'ConnectionResetError',
    'ошибка_конца_файла': 'EOFError',
    'многоточие': 'Ellipsis',
    'предупреждение_кодировки': 'EncodingWarning',
    'ошибка_окружения': 'EnvironmentError',
    'группа_исключений': 'ExceptionGroup',
    'ошибка_существования_файла': 'FileExistsError',
    'ошибка_плавающей_точки': 'FloatingPointError',
    'ошибка_отступа': 'IndentationError',
    'ошибка_прерывания': 'InterruptedError',
    'ошибка_каталога': 'IsADirectoryError',
    'ошибка_поиска': 'LookupError',
    'ошибка_модуля': 'ModuleNotFoundError',
    'ошибка_не_каталога': 'NotADirectoryError',
    'не_реализовано_значение': 'NotImplemented',
    'ошибка_переполнения': 'OverflowError',
    'ошибка_разрешения': 'PermissionError',
    'ошибка_поиска_процесса': 'ProcessLookupError',
    'ошибка_финализации_python': 'PythonFinalizationError',
    'ошибка_рекурсии': 'RecursionError',
    'ошибка_ссылки': 'ReferenceError',
    'синтаксическая_ошибка': 'SyntaxError',
    'системная_ошибка': 'SystemError',
    'ошибка_табуляции': 'TabError',
    'ошибка_таймаута': 'TimeoutError',
    'ошибка_нелокальной_переменной': 'UnboundLocalError',
    'ошибка_декодирования_юникода': 'UnicodeDecodeError',
    'ошибка_кодирования_юникода': 'UnicodeEncodeError',
    'ошибка_юникода': 'UnicodeError',
    'ошибка_перевода_юникода': 'UnicodeTranslateError',
    'ошибка_виндовс': 'WindowsError',
    'ошибка_неполного_ввода': '_IncompleteInputError',
    'асинхронный_итератор': 'aiter',
    'асинхронный_следующий': 'anext',
    'аски': 'ascii',
    'утверждать': 'assert',
    'точка_остановки': 'breakpoint',
    'вызываемый': 'callable',
    'компилировать': 'compile',
    'авторское_право': 'copyright',
    'благодарности': 'credits',
    'делить_с_остатком': 'divmod',
    'вычислять': 'eval',
    'исполнять': 'exec',
    'замороженное_множество': 'frozenset',
    'является': 'is',
    'лицензия': 'license',
    'генерировать': 'yield',
    # Технические термины Python (перенесено из пользовательского словаря)
    'список': 'list',
    'словарь': 'dict',
    'множество': 'set',
    'кортеж': 'tuple',
    'строка': 'str',
    'байты': 'bytes',
    'байтовый_массив': 'bytearray',
    'память': 'memoryview',
    'число': 'int',
    'вещественное': 'float',
    'комплексное': 'complex',
    'логическое': 'bool',
    'объект': 'object',
    'тип': 'type',
    'файл': 'file',
    'модуль': 'module',
    'метод': 'method',
    'функция': 'function',
    'класс': 'class',
    'экземпляр': 'instance',
    'атрибут': 'attribute',
    'аргумент': 'argument',
    'параметр': 'parameter',
    'итератор': 'iterator',
    'генератор': 'generator',
    'декоратор': 'decorator',
    'контекстный_менеджер': 'context_manager',
    'исключение': 'exception',
    'ошибка': 'error',
    'предупреждение': 'warning',
    'импорт': 'import',
    'пакет': 'package',
    'библиотека': 'library',
    'путь': 'path',
    'директория': 'directory',
    'каталог': 'folder',
    'фрейм': 'frame',
    'стек': 'stack',
    'трассировка': 'traceback',
    'главный': 'main',
    'инициализация': 'init',
    'удаление': 'del',
    'стр': 'str',
    'репр': 'repr',
    'вызов': 'call',
    'получить_элемент': 'getitem',
    'установить_элемент': 'setitem',
    'удалить_элемент': 'delitem',
    'итер': 'iter',
    'следующий': 'next',
    'вход': 'enter',
    'выход': 'exit',
    'равно': 'eq',
    'не_равно': 'ne',
    'меньше': 'lt',
    'меньше_равно': 'le',
    'больше': 'gt',
    'больше_равно': 'ge',
    'слоты': 'slots',
    'булево': 'bool',
    'все': 'all',
    'любой': 'any',
    'абс': 'abs',
    'длина': 'len',
    'сумма': 'sum',
    'минимум': 'min',
    'максимум': 'max',
    'отсортировать': 'sorted',
    'перечислить': 'enumerate',
    'сцепить': 'zip',
    'карта': 'map',
    'фильтр': 'filter',
    'диапазон': 'range',
    'обратный': 'reversed',
    'открыть': 'open',
    'ввод': 'input',
    'печать': 'print',
    'айди': 'id',
    'помощь': 'help',
    'дир': 'dir',
    'глобальные': 'globals',
    'локальные': 'locals',
    'свойства': 'vars',
    'супер': 'super',
    'свойство': 'property',
    'классметод': 'classmethod',
    'статметод': 'staticmethod',
    'установить_атрибут': 'setattr',
    'получить_атрибут': 'getattr',
    'удалить_атрибут': 'delattr',
    'есть_атрибут': 'hasattr',
    'экземпляр_класса': 'isinstance',
    'подкласс': 'issubclass',
    'ошибка_типа': 'TypeError',
    'ошибка_значения': 'ValueError',
    'ошибка_ключа': 'KeyError',
    'ошибка_индекса': 'IndexError',
    'ошибка_атрибута': 'AttributeError',
    'ошибка_импорта': 'ImportError',
    'ошибка_имени': 'NameError',
    'ошибка_деления_на_ноль': 'ZeroDivisionError',
    'ошибка_файла': 'FileNotFoundError',
    'ошибка_ввода_вывода': 'IOError',
    'ошибка_ос': 'OSError',
    'ошибка_выполнения': 'RuntimeError',
    'не_реализовано': 'NotImplementedError',
    'стоп_итерация': 'StopIteration',
    'стоп_асинхронная_итерация': 'StopAsyncIteration',
    'ошибка_утверждения': 'AssertionError',
    'ошибка_памяти': 'MemoryError',
    'системный_выход': 'SystemExit',
    'прерывание_клавиатурой': 'KeyboardInterrupt',
    'выход_генератора': 'GeneratorExit',
    'базовое_исключение': 'BaseException',
    'исключение': 'Exception',
    'предупреждение': 'Warning',
    'пользовательское_предупреждение': 'UserWarning',
    'устаревшее_предупреждение': 'DeprecationWarning',
    'ожидаемое_устаревшее_предупреждение': 'PendingDeprecationWarning',
    'синтаксическое_предупреждение': 'SyntaxWarning',
    'предупреждение_выполнения': 'RuntimeWarning',
    'будущее_предупреждение': 'FutureWarning',
    'предупреждение_импорта': 'ImportWarning',
    'предупреждение_юникода': 'UnicodeWarning',
    'предупреждение_байтов': 'BytesWarning',
    'предупреждение_ресурса': 'ResourceWarning',
    # Ключевые слова
    'и': 'and',
    'или': 'or',
    'не': 'not',
    'если': 'if',
    'иначе': 'else',
    'elif': 'elif',
    'для': 'for',
    'в': 'in',
    'пока': 'while',
    'функция': 'def',
    'класс': 'class',
    'вернуть': 'return',
    'продолжить': 'continue',
    'прервать': 'break',
    'попробовать': 'try',
    'кроме': 'except',
    'наконец': 'finally',
    'выбросить': 'raise',
    'с': 'with',
    'как': 'as',
    'глобально': 'global',
    'нелокально': 'nonlocal',
    'лямбда': 'lambda',
    'ожидать': 'await',
    'асинхронно': 'async',
    'импорт': 'import',
    'из': 'from',
    'удалить': 'del',
    'проход': 'pass',
    'истина': 'True',
    'ложь': 'False',
    'ничего': 'None',
    'встроенно': 'builtin',
    'вложенно': 'nested',
    # Встроенные функции (основные)
    '__имя__': '__name__',
    "'__главный__'": "'__main__'",
    "'__инциализация__'": "'__init__'",
    "'стр'": "'__str__'",
    "'репр'": "'__repr__'",
    "'дел'": "'__del__'",
    "'док'": "'__doc__'",
    "'файл'": "'__file__'",
    "'путь'": "'__path__'",
    "'версия'": "'__version__'",
    "'модуль'": "'__module__'",
    "'класс'": "'__class__'",
    "'словарь'": "'__dict__'",
    "'вызов'": "'__call__'",
    "'длина'": "'__len__'",
    "'получить'": "'__getitem__'",
    "'установить'": "'__setitem__'",
    "'удалить_элемент'": "'__delitem__'",
    "'итератор'": "'__iter__'",
    "'следующий'": "'__next__'",
    "'вход'": "'__enter__'",
    "'выход_контекст'": "'__exit__'",
    "'равно'": "'__eq__'",
    "'не_равно'": "'__ne__'",
    "'меньше'": "'__lt__'",
    "'меньше_равно'": "'__le__'",
    "'больше'": "'__gt__'",
    "'больше_равно'": "'__ge__'",
    "'слоты'": "'__slots__'",
    "'булево'": "'__bool__'",
    "'все'": "'__all__'",
    # Специальные переменные
    'сам': 'self',
    'печать': 'print',
    'длина': 'len',
    'ввод': 'input',
    'диапазон': 'range',
    'список': 'list',
    'словарь': 'dict',
    'множество': 'set',
    'кортеж': 'tuple',
    'максимум': 'max',
    'минимум': 'min',
    'сумма': 'sum',
    'открыть': 'open',
    'тип': 'type',
    'супер': 'super',
    'карта': 'map',
    'фильтр': 'filter',
    'все': 'all',
    'любой': 'any',
    'перечислить': 'enumerate',
    'обратный': 'reversed',
    'отсортировать': 'sorted',
    'классметод': 'classmethod',
    'статметод': 'staticmethod',
    'свойство': 'property',
    'удал_атрибут': 'delattr',
    'получить_атрибут': 'getattr',
    'установить_атрибут': 'setattr',
    'есть_атрибут': 'hasattr',
    'айди': 'id',
    'помощь': 'help',
    'выход': 'exit',
    'выходить': 'quit',
    'объект': 'object',
    'число': 'int',
    'строка': 'str',
    'логика': 'bool',
    'плавающий': 'float',
    'комплекс': 'complex',
    'байты': 'bytes',
    'байтовый_массив': 'bytearray',
    'память': 'memoryview',
    'округлить': 'round',
    'степень': 'pow',
    'абс': 'abs',
    'хэш': 'hash',
    'формат': 'format',
    'шестнадцатеричный': 'hex',
    'восьмеричный': 'oct',
    'двоичный': 'bin',
    'символ': 'chr',
    'ордина': 'ord',
    'срез': 'slice',
    'свойства': 'vars',
    'локальные': 'locals',
    'глобальные': 'globals',
    'следующий': 'next',
    'итерация': 'iter',
    'исключение': 'Exception',
    'ошибка': 'Error',
}
